@@ -36,7 +36,7 @@ except:
     isHildon=False
 
 
-version="0.2"
+version="0.3"
 
 if not isHildon:
     class  hildon:
@@ -506,16 +506,18 @@ class EditPanel(Panel):
 
 class ChangePasswordPanel(Panel):
 
-    def __init__(self, main):
+    def __init__(self, main, initial=False):
         Panel.__init__(self, main)
+        self.initial=initial
 
         # Tool Bar
         hbox=gtk.HBox()
         self.vbox.pack_end(hbox, expand=False)
 
         self.commitButton=self.addButton('Commit', self.commitCb)
-        self.addButton('Cancel', self.cancelCb)
-        self.lockButton=self.addButton('Lock', self.main.lockCb, packAtEnd=True)
+        if not initial:
+            self.addButton('Cancel', self.cancelCb)
+            self.lockButton=self.addButton('Lock', self.main.lockCb, packAtEnd=True)
 
         # Main Area
         vbox2=gtk.VBox()
@@ -552,7 +554,8 @@ class ChangePasswordPanel(Panel):
         self.pw1Entry.set_text('')
         self.pw1Entry.grab_focus()
         self.pw2Entry.set_text('')
-        self.main.startAlarm()
+        if not self.initial:
+            self.main.startAlarm()
         
     def setStatus(self, msg):
         self.status.set_text(msg)
@@ -778,7 +781,8 @@ class Main(hildon.Program):
         self.openPanel=OpenPanel(self)
         self.mainPanel=MainPanel(self)
         self.editPanel=EditPanel(self)
-        self.changePasswordPanel=ChangePasswordPanel(self)
+        self.changePasswordPanel=ChangePasswordPanel(self, False)
+        self.initialChangePasswordPanel=ChangePasswordPanel(self, True)
 
         self.toplevel.connect("delete_event", self.destroyCb)
 
@@ -802,7 +806,7 @@ class Main(hildon.Program):
         if os.path.isfile(self.encryptedFileName):
             self.openPanel.activate()
         else:
-            self.changePasswordPanel.activate('You need to provide a password for the database')
+            self.initialChangePasswordPanel.activate('You need to provide a password for the database')
         gtk.main()
 
         
